// load the individual files into Stata
qui{
	cap erase "..\1 - mep - raw, all.dta"

	forvalues w = 1/6{
		import excel "MEP raw\MEP `w'. Master Raw Data.xlsx", sheet("Groups") firstrow clear
		cap rename A IDNUMBER
		cap rename EPGROUP EPPARTYGROUP
		
		gen wave = `w'
		
		// parse all dates
		foreach x of varlist DOB ENTRY EXIT{
			
			// convert into string
			tempvar str
			tostring `x', gen(`str')
			
			local stub = strlower("`x'")
			gen double `stub' = date(`str', "YMD")
			format `stub' %td
			
			order `stub', after(`x')
			drop `x' `str'

		}

		// append, save
		if `w'>1 append using "..\1 - mep - raw, all.dta"
		sort IDNUMBER entry
		compress
		save "..\1 - mep - raw, all.dta", replace
	}

	// input wave 7 manually (from re-scraped Excel spreadsheet, 06JUL16)
	import excel "mep raw\EP7 (JUL16).xlsx", sheet("Sheet2") firstrow clear
		gen wave = 7
		
		replace DOB = "." if(DOB=="NA")
		destring DOB, replace
		
		// parse all dates
		foreach x of varlist DOB ENTRY EXIT{
			
			// convert into string
			tempvar str
			tostring `x', gen(`str')
			
			local stub = strlower("`x'")
			gen double `stub' = date(`str', "YMD")
			format `stub' %td
			
			order `stub', after(`x')
			drop `x' `str'
		}

		append using "..\1 - mep - raw, all.dta"
			sort IDNUMBER entry
			compress
		save "..\1 - mep - raw, all.dta", replace

	// Merge in some names from the original MEP w7 dataset, because current dataset is rough.
	tempfile w7Excel w7Names
	import excel "`imp'MEP raw\MEP 7. Master Raw Data.xlsx", sheet("Groups") firstrow clear
		
		cap rename A IDNUMBER
		cap rename EPGROUP EPPARTYGROUP
		
		// parse all dates
		foreach x of varlist DOB ENTRY EXIT{
			
			// convert into string
			tempvar str
			tostring `x', gen(`str')
			
			local stub = strlower("`x'")
			gen double `stub' = date(`str', "YMD")
			format `stub' %td
			
			order `stub', after(`x')
			drop `x' `str'
		}
		
		gen wave = 7
		
		rename *, lower
		rename idnumber memberid
		
		save `w7Excel', replace
		
		duplicates drop memberid, force
		save `w7Names', replace
}	
*********************************************************
use "..\1 - mep - raw, all.dta", clear

// One MEP doesn't have an ID number (BOSERUP Bodil from DEN).  OUP dataset has him as 1738.
recode IDNUMBER (.=1738)
rename IDNUMBER memberid
rename *, lower

replace name = trim(name)

// Toss Croatian observer from wave 7
drop if(memberid==112753)

// Fixing weird merges where we somehow gain an extra digit for memberid
	replace memberid = 96958 if(name=="William (The Earl of) DARTMOUTH")
	replace memberid = 124287 if(name=="Christine REVAULT D'ALLONNES BONNEFOY")
	replace memberid = 28266 if(name=="Sophia in 't VELD")
	
order wave, after(memberid)

// Merge in wave 7 names, to try to help
* go by id + wave + entry first, to get as much info as possible
merge memberid wave entry using `w7Excel', uniqusing nokeep sort update
tab _m wave		// 55.
drop _m

* go by id + wave only, to get at least the names.
merge memberid wave using `w7Names', uniqusing nokeep sort update keep(lastname firstname)
tab _m wave		// 907.
drop _m

replace name = firstname + " " + lastname if(name=="")
	
// Fix country for László TŐKÉS (memberid==39726)
replace country = "Romania" if(memberid==39726 & wave<8)
replace country = "Hungary" if(memberid==39726 & wave>=8)

	
// Manually fix all the entry and exit dates
	gen waveStart = .
	gen waveEnd = .
	format waveStart waveEnd %td
	
	* Wave 1:
	local wv = 1
		replace waveStart = date("19790801", "YMD") if(wave==`wv')
		replace waveEnd = date("19840601", "YMD") if(wave==`wv')
		
	* Wave 2:
	local wv = 2
		replace waveStart = date("19840801", "YMD") if(wave==`wv')
		replace waveEnd = date("19890601", "YMD") if(wave==`wv')
		
	* Wave 3:
	local wv = 3
		replace waveStart = date("19890801", "YMD") if(wave==`wv')
		replace waveEnd = date("19940601", "YMD") if(wave==`wv')
		
	* Wave 4:
	local wv = 4
		replace waveStart = date("19940801", "YMD") if(wave==`wv')
		replace waveEnd = date("19990601", "YMD") if(wave==`wv')
		
	* Wave 5:
	local wv = 5
		replace waveStart = date("19990801", "YMD") if(wave==`wv')
		replace waveEnd = date("20040601", "YMD") if(wave==`wv')		
		
	* Wave 6:
	local wv = 6
		replace waveStart = date("20040801", "YMD") if(wave==`wv')
		replace waveEnd = date("20090601", "YMD") if(wave==`wv')		

		* end date needs fixing: currently down for july 1, 2009
		
	* Wave 7:
	local wv = 7
		replace waveStart = date("20090801", "YMD") if(wave==`wv')
		replace waveEnd = date("20140601", "YMD") if(wave==`wv')	
		
		* wave end needs fixing (b/c not in dataset)

		
// Earliest EP election dates for next wave
	gen waveEnd_elMin = .
	format waveEnd_elMin %td
	label variable waveEnd_elMin `"Earliest EP election date for the following session (dates vary by country)"'
	
	
	* Wave 1:
	local wv = 1
		replace waveEnd_elMin = date("19840614", "YMD") if(wave==`wv')
		
	* Wave 2:
	local wv = 2
		replace waveEnd_elMin = date("19890615", "YMD") if(wave==`wv')
		
	* Wave 3:
	local wv = 3
		replace waveEnd_elMin = date("19940609", "YMD") if(wave==`wv')
		
	* Wave 4:
	local wv = 4
		replace waveEnd_elMin = date("19990610", "YMD") if(wave==`wv')
		
	* Wave 5:
	local wv = 5
		replace waveEnd_elMin = date("20040610", "YMD") if(wave==`wv')
		
	* Wave 6:
	local wv = 6
		replace waveEnd_elMin = date("20090604", "YMD") if(wave==`wv')		
		
	* Wave 7:
	local wv = 7
		replace waveEnd_elMin = date("20140522", "YMD") if(wave==`wv')	
		
		/*
			Wave 1: 14 June 1984

			Wave 2: 15 June 1989

			Wave 3: 9 June 1994

			Wave 4: 10 June 1999

			Wave 5: 10 June 2004

			Wave 6: 4 June 2009

			Wave 7: 22 May 2014
		*/

		
// Toss any phantom observations--those where the start date for the MEP is after the end of the wave, e.g.
format entry exit %td
count if entry>waveEnd
	tab wave if entry>waveEnd	// All from Wave 5.
	
drop if entry>waveEnd
		
// check for multiple appearances within a wave.  (Which can happen.  Unfortunately.)		
bysort memberid wave (entry): gen prevExit = exit[_n-1]	
format prevExit %td
order prevExit, before(entry)

count if(prevExit+1 != entry & prevExit!=. & prevExit<entry)	//the last part of the conditional is for people that picked up more groups during their tenure within a wave
gen flag = (prevExit+1 != entry & prevExit!=. & prevExit<entry)
		
	// They all seem to be legit cases.  So, generate a within-wave counter, so that the unique ID ends up being memberid-wave-counter.
	bysort memberid wave (entry): gen wvCnt = sum(flag) // it comes out to be 17 observations ==1 and not 15 b/c because memberid 1566 changed groups a bunch after she came back (so she has two more entries than usual); 15 + 2 = 17.
	replace wvCnt = wvCnt + 1
	drop flag
	
// force all the entry and exit dates to match for a wave (based on notes from Skype; can also reverify with tab wave if exit>waveEnd )
	* wave 1: no adjustments
	
	* wave 2: no adjustments
	
	* wave 3: no adjustments
	
	* wave 4: no adjustments
	
	* wave 5: wave end needs fixing
	  replace exit = waveEnd if(wave==5 & exit>td(01jun2004)) // /* july 19, 2004 AND august 1, 2004*/ 
	  
	* wave 6: wave end needs fixing
	replace exit = waveEnd if(wave==6 & exit>td(01jun2009))
	
	* wave 7: now appears to be fine, with the reimport
	
	
// collapse the same MEPs within wave-counters - take earliest and latest in new var.  Toss the spare.  Will result in one obsv. for each MEP-wave.
bysort memberid wave wvCnt (entry): egen entry_min = min(entry)
bysort memberid wave wvCnt (entry): egen exit_max = max(exit)
format entry_min exit_max %td		

	duplicates drop memberid wave wvCnt, force // force drop duplicates.

	
// calculate durations.
* by wave
gen double daysWv = exit_max - entry_min
label variable daysWv "Duration, from start of current wave (in days)"


gen last = regexs(0) if(regexm(name, "[A-Z]+$"))
	gen temp = regexs(0) if(regexm(name, "[A-Z]+\-[A-Z]+$"))
	replace last = temp if(temp!="")
	drop temp
	
gen last2 = regexs(0) if(regexm(lastname, "[A-Z]+$"))
	gen temp = regexs(0) if(regexm(lastname, "[A-Z]+\-[A-Z]+$"))
	replace last2 = temp if(temp!="")
	drop temp
replace last = last2 if(last=="")

*** NOTE TO SELF: check the reentries again after merging in the book data, to see if they stay in our estimation sample.
preserve
	tempfile names
	keep if(wave==7 & memberid>=100000)
	duplicates drop memberid wave, force
	
	// Deal with the two Brits
	replace last = "TAYLOR R" if(name=="Rebecca TAYLOR")
	replace last = "TAYLOR K" if(name=="Keith TAYLOR")
	
	// Recode the 7 Croats whose last names didn't encode correctly
	replace last = upper("Rados") if(memberid==112753)
	replace last = upper("Plenkovic") if(memberid==112755)
	replace last = upper("VULJANIC") if(memberid==112760)
	replace last = upper("TOMASIC") if(memberid==119431)
	replace last = upper("MALETIC") if(memberid==119436)
	replace last = upper("BUSIC") if(memberid==119438)

	// Replace the one Czech
	replace last = upper("MYNAR") if(memberid==114873)
	
	// The last name changes to match what's in OUP dataset.
	replace last = "BORRISOV" if(last=="BORISSOV")
	replace last = "GHIKOPOULOS" if(last=="GKIKOPOULOS")
	replace last = "SADURSKIS" if(last=="ADURSKIS")
	replace last = "KOZLOWSKI" if(last=="OWSKI")
	replace last = "FERNANDEZ" if(last=="NDEZ")
	replace last = "PEREZ" if(last=="REZ")
	replace last = "ANDERSDOTTIR" if(last=="ANDERSDOTTER") 
	replace last = "SUICA" if(last=="UICA") 
	replace last = "GALL-PELCZ" if(last=="LL-PELCZ") 
	replace last = "KOVACS" if(last=="CS") 
	replace last = "HIDVEGHI" if(last=="GHI") 
	replace last = "BANKI" if(last=="NKI") 
	replace last = "BONANI" if(last=="BONANINI") // latter spelling is correct(?)
	replace last = "MCINTYRE" if(last=="INTYRE") 
	replace last = "ZERIBI" if(last=="RIBI") 
	
	rename memberid official
	
	save `names', replace
restore


// Fix the OUP data with the correct merges for the three nationality oopses.
preserve
	tempfile nats
	
	use "Daniel 2015 - OUP Replication Package/Daniel - OUP 2015 Replication Data.dta", clear
	rename id_number memberid
	rename name lastname
	
	// to be absolutely positive we aren't getting the incorrect observations
	drop if(lastname=="MAZEJ KUKOVIC" | lastname=="DE MARTINI" | lastname=="TORVALDIS" | lastname=="TOKES")
	duplicates drop country_code wave, force
	
	keep country_code wave dpi_state norris lij
	save `nats', replace
restore


// Now, merge in the dropout stuff from book. 
preserve
	tempfile oup 
	
	use "Daniel 2015 - OUP Replication Package/Daniel - OUP 2015 Replication Data.dta", clear
	rename id_number memberid
	rename name lastname
	
	// ** Fix coding error for two nationalities (checked EP site; no indication that they switched nationalities for EP purposes)
	replace country = "Slovenia" if(lastname=="MAZEJ KUKOVIC")
		replace country_code = 24 if(lastname=="MAZEJ KUKOVIC")
	replace country = "Italy" if(lastname=="DE MARTINI")
		replace country_code = 14 if(lastname=="DE MARTINI")
		
		* No record in spreadsheet or EP website of Swede MEP with last name Torvaldis...
		* ...but there *is* a Finnish MEP with last name Torvalds.
		replace country = "Finland" if(lastname=="TORVALDIS")
			replace country_code = 8 if(lastname=="TORVALDIS")
		replace lastname = "TORVALDS" if(lastname=="TORVALDIS")
	
	// Deal with the odd merge for TOKES (b/c he goes from being an MEP from ROM for waves 6/7 to HUN in wave 8, which messed up the most recent wv 7 scrape we did)
	replace country = "Romania" if(memberid==39726 & wave<8)
	replace country_code = 22 if(memberid==39726 & wave<8)
	
	foreach x of varlist dpi_state norris lijp{
		replace `x' = . if(lastname=="MAZEJ KUKOVIC" | lastname=="DE MARTINI" | lastname=="TORVALDS" | lastname=="TOKES")	// to be absolutely positive we're only fixing these four MEPs' observations
	}
	
	
	// Need to go through and check/assign the real numbers to anyone OUP dataset gave a temp ID to in wave 7. 
	
		//rename countries, for later matching
		replace country = "Czech Republic" if(country=="Czech")
		replace country = "United Kingdom" if(country=="UK")
	
	gen last = regexs(0) if(regexm(lastname, "[A-Z]+$"))
		gen temp = regexs(0) if(regexm(lastname, "[A-Z]+\-[A-Z]+$"))
			replace last = temp if(temp!="")
			drop temp
		replace last = "TAYLOR R" if(lastname=="TAYLOR Rebecca")
		replace last = "TAYLOR K" if(lastname=="TAYLOR")
		
	count if(last=="" & wave==7) // good--all names for wave 7 are non-missing
	
	merge last country wave using `names', uniqusing sort keep(official)
		
		* First, is there even a problem?  (Supposing that it's only true member IDs >=100000 that may have an issue (implying OUP IDs >=100000, too))
		qui levelsof memberid if(_m==3 & memberid>100000), local(book)
		qui levelsof official if(_m==3), local(off)
		local overlap: list book & off
		di "`overlap'"	// Appears that there's only one ID >110000 in both sets of lists.  Importantly, that suggests there's no one that OUP 
						// assigned an ID to in his book that officially belongs to another MEP, per the scraped data.
	
	tab country _merge  if(memberid>100000 & wave==7)
	
		// Handcoding the problematic _m==1 cases (which most likely have true member IDs less than 110000)
		replace official = 96848 if(last=="GABRIEL" & country=="Bulgaria" & wave==7)
		replace official = 28336 if(last=="FLASAROVA" & country=="Czech Republic" & wave==7)
		replace official = 37200 if(last=="SAKS" & country=="Estonia" & wave==7)
		replace official = 96685 if(last=="PAKARINEN" & country=="Finland" & wave==7)
		replace official = 96947 if(last=="BERRA" & country=="France" & wave==7)
		replace official = 1202 if(last=="COCHET" & country=="France" & wave==7)
		replace official = 30482 if(last=="OMARJEE" & country=="France" & wave==7)
		replace official = 2315 if(last=="COTTIGNY" & country=="France" & wave==7)
		replace official = 30475 if(last=="BERNARD" & country=="Lithuania" & wave==7)
		replace official = 37448 if(last=="HELLVIG" & country=="Romania" & wave==7)
		replace official = 33991 if(last=="SILAGHI" & country=="Romania" & wave==7)
		replace official = 39916 if(last=="KUKOVIC" & country=="Slovenia" & wave==7)
		replace official = 23691 if(last=="KACIN" & country=="Slovenia" & wave==7)
		
	
	
	replace memberid = official if(official!=.)
	

	// Do we have all unique IDs, still?
	duplicates list memberid wave
		* No, we don't.  Why not?
		
		// memberid = 23691
			* The MEP's name is Jelko KACIN.  We have an entry for both his first and last name (Lord help us all.)
			drop if(memberid==23691 & lastname=="JELKO")
			
		// memberid = 96685
			* MANNER is PAKARINEN's maiden name.  (https://github.com/briatte/epam/blob/master/data.r)
			drop if(memberid==96685 & lastname=="MANNER")
			
		// memberid = 96848
			* GABRIEL is NEDELCHEVA's maiden name. (https://github.com/briatte/epam/blob/master/data.r)
			drop if(memberid==96848 & lastname=="GABRIEL")
			
		// memberid = 105192	
			* Accidentally overwrote a correct ID.  Garcia Perez's ID is different from what's in the current dataset (but right in the book's original.)
			* IRIGOYEN PEREZ's ID number is indeed 105192.
			replace memberid = 28289 if(wave==7 & lastname=="GARCIA PEREZ")
		
		
	// Unique IDs now?
	duplicates list memberid wave
		* Yes.
		

	rename _merge _mergeMain
	
	// Fix the covariates for the troublesome countries
	merge country_code wave using `nats', uniqusing sort nokeep update
	tab _merge _mergeMain
	
	save `oup', replace
	
	
restore

merge memberid wave using `oup', ///
				uniqusing sort /*nokeep*/ ///
				keep(lastname country terms_served dropout outcome dpi_state norris_federalism lijp terms_served dropout EP_leader leadership age female christian_democrat socialist liberal green communist euroskeptic conservative non_inscrit wave6 wave5 wave4 wave3 wave2 wave1 rapport country_code natl_govt euro_salary)	// !! Add additional merges here.			// NOTE: got rid of nokeep, so Will could see what's in the OUP but not raw (==2)
	tab _merge	// some don't match.  Can deal with later.
	tab wave _merge 	// Only 6 from the book that don't match the assembled dataset.  Not bad.
						// 352 that appear in spreadsheets, but not book (likely observers to EP for pre-accession countries)
order country_code, after(country)
rename _merge _mergeOUP		// eventually rename again

	
// Fix the two odd cases where some of the party dummies don't code?
egen partyCheck = rowmiss(christian_democrat socialist liberal green communist euroskeptic conservative non_inscrit)
tab partyCheck if(_mergeOUP==3)	// the partyCheck==3 cases are the odd ones

recode euroskeptic conservative non_inscrit (.=0) if(wave==7 & (memberid==23704 | memberid==26851))
drop partyCheck

// Also fix the missing terms_served observations.  For the six observations that have values for all the other vars, they're all freshmen.  (See WTD's 21JUL16 2135 SST email.)
recode terms_served (.=1) if(age!=.)


// Fill in country codes for future merges.
bysort country: egen cc = max(country_code)
count if(cc !=country_code & country_code!=.)

replace country_code = cc if(country_code==.)
drop cc	
	
// Remerge the country data, for the two weird missing observations.
merge country_code wave using `nats', uniqusing sort nokeep update
tab _merge
drop _merge

// Manually code the other values for the two remaining troublesomes.
	* BICEP (memberid==113891)
	local mi = 113891
	recode rapports (.=0) if(memberid==`mi')
	recode EP_leader leadership (.=0) if(memberid==`mi')
	recode female (.=0) if(memberid==`mi')
	replace age = floor( (entry_min-dob) /365.25) if(memberid==`mi')
	recode green (.=1) if(memberid==`mi')
	recode christian-non_insc (.=0) if(memberid==`mi')
	recode terms_served (.=1) if(memberid==`mi' & wave==7)
	recode natl_govt (.=0) if(memberid==`mi' & wave==7) 	// French socialists in power during wave 7.  BICEP is a green.
	
	* BARRACCIU (memberid==116823)
	local mi = 116823
	recode rapports (.=0) if(memberid==`mi')
	recode EP_leader leadership (.=0) if(memberid==`mi')
	recode female (.=1) if(memberid==`mi')
	replace age = floor( (entry_min- dob ) /365.25) if(memberid==`mi')
	recode socialist (.=1) if(memberid==`mi')
	recode christian-non_insc (.=0) if(memberid==`mi')
	recode terms_served (.=1) if(memberid==`mi' & wave==7)
	recode natl_govt (.=1) if(memberid==`mi' & wave==7)		// Looks like coalition government of Christian democrats + socialists are in power during wave 7 in Italy.  BARRACCIU is a socialist.
	
	* the wave FEs (for anyone that's missing the info)
	forv w=1/6{
		recode wave`w' (.=1) if(wave==`w')
		recode wave`w' (.=0) if(wave!=`w')
	}
	
	
// Merge the date of the election right before this wave started.
preserve
	tempfile elects
	use "Turnover - Election Dates.dta", clear
	
	bysort country_code before (election): keep if(_N==_n)
	
	rename before wave
	save `elects', replace
restore


merge country_code wave using `elects', uniqusing sort keep(election) nokeep
	tab _merge
	drop _merge
	
gen daysLastElect = waveStart - election
label variable daysLastElect `"Days since last national election @ wave's start date"'


// Electoral system data--EP elects (20JUL16)
merge country_code wave using "Elec systems - EP elections.dta", uniqusing sort nokeep
drop wvYear
tab _merge
drop _merge

	// Fill in the missing data (b/c the countries enter in that wave) by backfilling 
	local stub = "EP"	
	
		* code Estonia manually as Open for wave 5 (b/c it switches between waves 6 and 7)
		replace sysOpen_`stub' = 1 if(sysEP=="." & country=="Estonia" & wave==5)
		replace sys`stub' = "Open" if(sysEP=="." & country=="Estonia" & wave==5)

	qui levelsof sys`stub', local(sys)
	foreach s of local sys{
		if("`s'"!="."){
			bysort country: egen tempMax = max(sys`s'_`stub')
			replace sys`s'_`stub' = tempMax if(sysEP==".")
			replace sys`stub' = "`s'" if(sys`s'_`stub'==1 & sysEP==".")
			drop tempMax
		}
	}
	
	
// Periphery + Intercapital distance + Electoral system data--nat'l elects 
gen periph =  (	country=="Ireland" | country=="Portugal" | country=="Spain" ///
			 |	country=="Italy"   | country=="Cyprus"   | country=="Malta" ///
			 |	country=="Greece"  | country=="Bulgaria" | country=="Lithuania" ///
			 |	country=="Latvia"  | country=="Estonia"  | country=="Finland")
label variable periph `"Whitaker 2004: =1 if periphery country, =0 if core"'

preserve
	tempfile distance
	
	import excel "BXLdistance.xls", sheet("Sheet1") firstrow clear
	local stub = "Nat"
	rename natlsystem sys`stub'
	replace sys`stub' = trim(sys`stub')
	
	replace sys`stub' = "Ord" if(sys`stub'=="Ordered")
	qui levelsof sys`stub', local(sys)
	foreach s of local sys{
		local s = trim("`s'")
		if("`s'"!="."){
			gen sys`s'_`stub' = sys`stub'=="`s'"
			
			if("`s'"=="Ord"){
				label variable sys`s'_`stub' `"sys`stub'=="Ordered""' 
			}
		}
	}
	
	isid country_c	//OK, don't need to merge by wave, if there's only one observation for all the countries.
	save `distance', replace
restore

merge country_code using `distance', uniqusing sort


label variable BXLdistance `"Geodesic distance from capital to Brussels, in miles."'
drop term
	tab _merge
	drop _merge

rename _mergeOUP _merge

	
	
// code dropout for wave 7
replace dropout = 1 if(exit_max<waveEnd & wave==7)


// Coding anyone lasting to tax day or later as staying the whole term (i.e., they don't dropout) => code in reverse, because it's the ==0 people that are the problem.
recode dropout (0=1) if(exit_max < waveEnd & _m==3 & (  ((month(exit_max)==4 & day(exit_max)<15) & year(exit_max)==year(waveEnd)) | (month(exit_max)<4 & year(exit_max)==year(waveEnd))  ))
	
// Fix the odd casees. 
	* If they dropout before 15APR of the election year, they need to be coded as 1 (for dropping out), not 0.
	recode dropout (0=1) if(exit_max < waveEnd & _m==3 & !(((month(exit_max)==4 & day(exit_max)<15) & year(exit_max)==year(waveEnd)) | (month(exit_max)<4 & year(exit_max)==year(waveEnd))  ))

	* If they stay until the end, they need to be coded as 0 (for staying), not 1.
	recode dropout (1=0) if(exit_max >= waveEnd & _m==3)
	
rename dropout dropoutOld
label variable dropoutOld "Original variable"

// *Force* the manual recode.  For every observation where _m==3.
gen dropout = .
recode dropout (.=1) if(exit_max < waveEnd & _m==3 & ( ((month(exit_max)==4 & day(exit_max)<15) & year(exit_max)==year(waveEnd)) | (month(exit_max)<4 & year(exit_max)==year(waveEnd)) | year(exit_max)<year(waveEnd)  ))
recode dropout (.=0)	
	order dropout, before(dropoutOld)
	label variable dropout "==1 if MEP left wave before 15APR of wave's ending year, 0 otherwise"
	
label define outcome 0 "retire" 1 "exec @ ctry" 2 "EU inst (not EP)" 3 "leg @ ctry" 4 "reelected @ EP"
label values outcome outcome

// merge in the observer variable, see if any snuck through.	
rename _merge _mTT
merge memberid using "observer scrape/all, v1 (observers only).dta", uniqusing sort nokeep keep(observer startMin endMax)
tab _merge

	//OK, now.  See if anyone is an observer during the time period in question.
	gen obsvYes = observer==1 & (endMax>entry_min | exit_max<startMin)
	label variable obsvYes "observer==1 & (endMax>entry_min | exit_max<startMin)"
	tab obsvYes
		// only 1.
	drop if(obsvYes==1)

drop _merge
rename _mTT _merge


// Get in COW's ccodes.
** Needs to be before Seki and Williams import
gen ccode = .
	replace ccode=	305	if(country=="Austria")
	replace ccode=	211	if(country=="Belgium")
	replace ccode=	355	if(country=="Bulgaria")
	replace ccode=	344	if(country=="Croatia")
	replace ccode=	352	if(country=="Cyprus")
	replace ccode=	316	if(country=="Czech Republic")
	replace ccode=	390	if(country=="Denmark")
	replace ccode=	366	if(country=="Estonia")
	replace ccode=	375	if(country=="Finland")
	replace ccode=	220	if(country=="France")
	replace ccode=	260	if(country=="Germany" & waveStart<year(1991))
	replace ccode=	255	if(country=="Germany" & waveStart>=year(1991))
	replace ccode=	350	if(country=="Greece")
	replace ccode=	310	if(country=="Hungary")
	replace ccode=	205	if(country=="Ireland")
	replace ccode=	325	if(country=="Italy")
	replace ccode=	367	if(country=="Latvia")
	replace ccode=	368	if(country=="Lithuania")
	replace ccode=	212	if(country=="Luxembourg")
	replace ccode=	338	if(country=="Malta")
	replace ccode=	210	if(country=="Netherlands")
	replace ccode=	290	if(country=="Poland")
	replace ccode=	235	if(country=="Portugal")
	replace ccode=	360	if(country=="Romania")
	replace ccode=	317	if(country=="Slovakia")
	replace ccode=	349	if(country=="Slovenia")
	replace ccode=	230	if(country=="Spain")
	replace ccode=	380	if(country=="Sweden")
	replace ccode=	200	if(country=="United Kingdom")
order ccode, after(country_code)
label variable ccode "COW country code"


// Bring in CIEP data from Seki and Williams
	cap drop _m
	gen startyear = year(waveStart)
	merge ccode startyear using "Seki and Williams Governments dataset/1 - Seki-Williams - governments (v2.0), v1 (CIEP only, UoA=SY).dta", uniqusing sort nokeep keep(ciep)
	drop startyear
	tab _m
	
	gen ciepDays = ciep * 365
		label variable ciepDays "CIEP, in days"
	gen daysLastElect_norm = daysLastElect/ciepDays		// can keep gradiated in days (it's being transformed into a percent, after all.  Should (and do) get the same general thing if I'd done months.
		label variable daysLastElect_norm "daysLastElect/ciepDays"
	
cd ..

order entry_min exit_max, before(entry)

drop last last2 entry exit

compress

saveold "1 - mep - raw, all.dta", replace version(12)

