use "1 - mep - raw, all.dta", clear
keep if _m==3	//	Keep only the merged data, for now

// rescale lijp so that it starts at 0 (for the interaction checks)
replace lijp = lijp - 1

bysort memberid wave (entry): gen nextEntry = entry_min[_n+1]	
	order nextEntry, after(exit_max)
	format nextEntry %td
	
// Set up the dataset
	// Duplicate obsvs, gen transition var + status
	expand 3, gen(spare)	
	bysort memberid wave wvCnt spare: gen transD = _n
		label variable transD "Trans ID, dropout vs. returning (no failure types)"
	
	gen status = spare==0
		label variable status "1 = transition observed"
		replace status = 0 if(dropout==0)
		
	label define stages 1 "Sitting MEP" 2 "Exit"

	gen stage = cond(transD==1|spare==0, 1,2)
	gen nextStage = cond(transD==2 & spare==1, 1,2)
		label values stage stages
		label values nextStage stages
	
	bysort memberid wave (entry_min): egen maxWvCnt = max(wvCnt)
	bysort memberid wave wvCnt (entry_min): egen maxDrop = max(dropout)
	
	* toss trans==2 for people that never dropout
	drop if(maxDrop==0 & transD==2)
	
	* everyone that drops out needs a chance to swing back.
	replace entry_min = exit_max if(spare==1 & transD==2)
	replace exit_max = waveEnd if(maxWvCnt==1 & spare==1 & transD==2)  	// for people that never return, the ending period is the last wave date.
	replace exit_max = nextEntry if(maxWvCnt!=1 & spare==1 & transD==2)	// for people bouncing back into the EP within the wave, the end date is the next intra-wave start date
		recode status (0=1) if(maxWvCnt!=1 & spare==1 & transD==2)
	replace status = 0 if(exit_max==. & maxWvCnt==2 & spare==1 & transD==2)  // for the two MEPs that leave *again*, after already dropping out and returning once
		replace exit_max = waveEnd if(exit_max==. & maxWvCnt==2 & spare==1 & transD==2) 
	
	// update the duration, idiot.
	replace daysWv = exit_max - entry_min
	
	
	duplicates tag memberid wave transD entry_min, gen(flag)
	drop if spare==1 & flag!=0

	sort memberid wave entry_min transD 
	
	drop spare flag	
	
	// force age to update for dropout and reentry obsvs.  (Just overwrite WTD's coding.  Sorry, Will.)
	gen ageTemp = floor( (entry_min-dob) /365.25) 
	replace age = ageTemp if(ageTemp!=.)
	drop ageTemp
	
	// rescale days to months
	gen mnthsLastElect = daysLastElect/30
	
	// get logged salary var, jic
	gen lnEuro_salary = ln(euro_salary)
	
	// Gen covariates 
	foreach x of varlist 	dpi_state norris_federalism lijp rapports mnthsLastElect terms_served EP_leader leadership age female ///
							christian_democrat socialist liberal green communist euroskeptic conservative non_inscrit  ///
							sysCPL_EP sysOpen_EP sysOrd_EP sysSMP_EP sysSTV_EP ///
							sysCPL_Nat sysMixed_Nat sysOpen_Nat sysOrd_Nat sysSMP_Nat sysSTV_Nat natl_govt ///
							periph BXLdistance ///
							euro_salary lnEuro_salary ///
							daysLastElect_norm ///
							wave6 wave5 wave4 wave3 wave2 wave1 {
		gen `x'_f1 = cond(transD==1,`x',cond(`x'==., ., 0))
		gen `x'_f2 = cond(transD==2,`x',cond(`x'==., ., 0))
	}
	
// Dummy out the dpi_state categories 
qui tab dpi_state, gen(dp_)
qui tab dpi_state_f1, gen(dp_f1_)
qui tab dpi_state_f2, gen(dp_f2_)

gen mnthsWv = daysWv/30
stset mnthsWv, fail(status==1)		//no t0 set needed because gap time.			// Change the stset var to get everything back in days or months.
gen t0 = 0


saveold "2 - mep - mstate ready.dta", replace version(12) nol
