// Load data
use "2 - mep - mstate ready.dta", clear

********************************************************************************
// Keep main estimation sample - amounts to anything where female (or communism) isn't missing.
drop if(female==.)


// General descriptives about dataset
qui tab memberid
return list
	// r(r) = number of individual MEPs

gen double idWave = memberid*10 + wave
qui tab idWave
return list
	// r(r) = number of wave-ID pairings
	
qui tab idWave if(maxWvCnt==1)
return list
	// r(r) = number of MEP-waves that appear once within a wave


// Table 1
tab stage nextStage if(status==1)
	
	* For percentages:
	qui{
		forvalues s = 1/2{
			qui count if(stage==`s')
				local den = `r(N)'
			qui count if(stage==`s' & status==1)
				local num = `r(N)'
				
			noi di as gr "Stage `s' perc: " as ye %3.1f (`num'/`den')*100
		}
	}

	
// Table 2
sum status mnthsWv ///
	dp_3 norris_federalism mnthsLastElect sysCPL_Nat ///
	sysCPL_EP age female communist if(transD==1 & wvCnt==1)

	
// Table 3
* Model 1
stcox 	dp_f?_3 norris_federalism_f? mnthsLastElect_f? sysCPL_Nat_f? ///
			wave6 wave5 wave4 wave3 wave2 wave1	 , ///
		strata(transD) nohr breslow

* Model 2
stcox 	dp_f?_3  norris_federalism_f? mnthsLastElect_f? sysCPL_Nat_f? sysCPL_EP ///
			age_f? female ///
			communist ///
			wave6 wave5 wave4 wave3 wave2 wave1  , ///
		strata(transD) nohr breslow

	// Specification checks
	{

		//  How did we decide which covariates to collapse and which to not?
		* full model with transition-specific everything
		stcox 	dp_f?_3  norris_federalism_f? mnthsLastElect_f?  sysCPL_EP_f? sysCPL_Nat_f? ///
				age_f? female_f? ///
				communist ///
				wave6 wave5 wave4 wave3 wave2 wave1  , ///
			strata(transD) nohr breslow

		// requires installing mstatecox package
		net install "http://www.shawnakmetzger.com/research/mstatecox", replace
		mstutil, from(stage) to(nextStage)
		mstphtest, log

		// The wave counters are the ones that seem to run into issues.
		// If we leave them uncollapsed, though, most seem to go away except for wave 1,
		//	which is **suggestive** (but certainly not definitive) that the stat sig PH
		//	results may be a byproduct of collapsing, in some cases.
		// However, can't fix any of the PH violations at the moment 
		//	b/c mstate in R doesn't accommodate the correction.
		
		
		* Wald test for equivalence
		test sysCPL_EP_f1==sysCPL_EP_f2  		// not SS.  Could collapse.
		test age_f1==age_f2						// close enough to different that we'll leave (WS)
		test female_f1==female_f2 				// not SS.  Could collapse.
		//(communist doesn't return sensible estimates when estimating separate effects, so it's already collapsed)
	}

* Model 3
stcox 	dp_f?_3 mnthsLastElect_f? sysCPL_Nat_f? sysCPL_EP ///
			age_f? female ///
			communist ///
			wave6 wave5 wave4 wave3 wave2 wave1  , ///
		strata(transD) nohr breslow
		
* Model 4
stcox 	norris_federalism_f? mnthsLastElect_f? sysCPL_Nat_f? sysCPL_EP ///
			age_f? female ///
			communist ///
			wave6 wave5 wave4 wave3 wave2 wave1  , ///
		strata(transD) nohr breslow		
