use "1 - mep - raw, all.dta", clear
keep if _m==3	//	Keep only the merged data

// Appendix A
contract country wave if(dropout==1), freq(num)

replace country ="UK" if(country=="United Kingdom")
merge country wave using "assembly files/EP Seats, by country-wave.dta", unique sort keep(seatTotal)

recode num (.=0) if(seatTotal!=.)

gen perc = num/seatTotal * 100
format perc %4.2f

noi tabdisp country wave, cellvar(num seatTotal perc) 	//NOTE: this number (if anything) overestimates the number of dropouts, because it could be the case that replacements for earlier dropouts *also* dropout.
rename perc percWthn


***********************************
use "2 - mep - mstate ready.dta", clear

// Appendix B
* Model 5
stcox 	dp_f?_3  norris_federalism_f? lijp_f? mnthsLastElect_f? sysCPL_Nat_f? sysCPL_EP  ///
			age_f? female ///
			communist ///
			wave6 wave5 wave4 wave3 wave2 wave1  , ///
		strata(transD) nohr breslow

* Model 6
	// Reestimate main model using the observations from Lijp sample
	stcox 	dp_f?_3  norris_federalism_f? mnthsLastElect_f? sysCPL_Nat_f? sysCPL_EP ///
			age_f? female ///
			communist ///
			wave6 wave5 wave4 wave3 wave2 wave1  if(lijp!=.), ///
		strata(transD) nohr breslow	

* Model 7	
	// Estimating main model with Lijp only using the observations from Lijp sample
stcox 	lijp_f? mnthsLastElect_f? sysCPL_Nat_f? sysCPL_EP ///
		age_f? female ///
		communist ///
		wave6 wave5 wave4 wave3 wave2 wave1  if(lijp!=.), ///
	strata(transD) nohr breslow	

	
// Appendix C
* including code for published figures only.

	* Generated in R. 
	* FILE: "Figure 3.R"	 [generates "figures/sim results/Simulations - Fig 4.Rdata" + Stata versions of the files]
	* FILE: "Figure 4.R"	 [generates "figures/sim results/Simulations - Fig 5.Rdata" + Stata versions of the files]
	
		*** CAUTION: Simulation code takes 30-90 minutes to run.
		*		 	 If only interested in replicating graphs, run the "graph - ..." do-files only
	  
// Once R files are all run:
qui do "figures/graph - Figure 3.do"
qui do "figures/graph - Figure 4.do"



// Appendix D
** NOTE: no PH tests run.
use "2 - mep - mstate ready.dta", clear

*>> Individual-Level Variables
	* EP leadership
	stcox 	dp_f?_3  norris_federalism_f? mnthsLastElect_f? sysCPL_Nat_f? sysCPL_EP ///
				EP_leader_f? ///
				age_f? female ///
				communist ///
				wave6 wave5 wave4 wave3 wave2 wave1  , ///
			strata(transD) nohr breslow
		
		* As one effect because of non-sensible estimates  (still not SS)
		stcox 	dp_f?_3  norris_federalism_f? mnthsLastElect_f? sysCPL_Nat_f? sysCPL_EP ///
				EP_leader ///
				age_f? female ///
				communist ///
				wave6 wave5 wave4 wave3 wave2 wave1  , ///
			strata(transD) nohr breslow

	* Terms served
	stcox 	dp_f?_3  norris_federalism_f? mnthsLastElect_f? sysCPL_Nat_f? sysCPL_EP ///
				terms_served_f? ///
				age_f? female ///
				communist ///
				wave6 wave5 wave4 wave3 wave2 wave1  , ///
			strata(transD) nohr breslow

	* Party group FEs
	stcox 	dp_f?_3  norris_federalism_f? mnthsLastElect_f? sysCPL_Nat_f? sysCPL_EP ///
				age_f? female ///
				christian_democrat liberal green communist euroskeptic conservative socialist ///
				wave6 wave5 wave4 wave3 wave2 wave1  , ///
			strata(transD) nohr breslow
			
	* Rapporteurships
	stcox 	dp_f?_3  norris_federalism_f? mnthsLastElect_f? sysCPL_Nat_f? sysCPL_EP ///
				rapports_f? ///
				age_f? female ///
				communist ///
				wave6 wave5 wave4 wave3 wave2 wave1  , ///
			strata(transD) nohr breslow

	* Salary
	stcox 	dp_f?_3  norris_federalism_f? mnthsLastElect_f? sysCPL_EP sysCPL_Nat_f? ///
				lnEuro_salary_f? ///
				age_f? female ///
				communist ///
				wave6 wave5 wave4 wave3 wave2 wave1  , ///
			strata(transD) nohr breslow

*>> Country- and (National) Party-Level Variables	
	* Normalized election clock
	stcox 	dp_f?_3  norris_federalism_f? daysLastElect_norm_f? sysCPL_EP sysCPL_Nat_f? ///
			age_f? female ///
			communist ///
			wave6 wave5 wave4 wave3 wave2 wave1  , ///
		strata(transD) nohr breslow

	* Personal incentive
	qui{				// merge in the variable
		cap drop _m
		
		preserve
			tempfile qog
		
			use "assembly files/QoG_t_s_v6Apr11 [standard], v0 (original).dta", clear
			drop ccode
			rename ccodecow ccode
			
			// 	There are some ccode-year pairings that aren't unique.  However, none 
			//	of them are EU countries, so just drop the duplicates and move on
			
			duplicates drop ccode year, force
			
			save `qog', replace
			
		restore
		
		gen year = year(waveStart)
		merge ccode year using `qog', uniqusing sort nokeep keep(dpi_pr jw_persr) nol nonotes

		replace jw_persr = -jw_persr
		qui sum jw_persr, detail
		gen jw_persr_d = jw_persr > `r(p50)'
			label variable jw_persr_d "jw_persr > `r(p50)'"
			
		drop year
		tab _m
		
		foreach x of varlist dpi_pr jw_persr jw_persr_d{
			gen `x'_f1 = cond(transD==1,`x',cond(`x'==., ., 0))
			gen `x'_f2 = cond(transD==2,`x',cond(`x'==., ., 0))
		}
		
		// redo the stset, because the merge is doing something weird
		stset mnthsWv, fail(status==1)	
	}	
	stcox 	dp_f?_3  norris_federalism_f? mnthsLastElect_f? sysCPL_EP sysCPL_Nat_f? ///
			age_f? female ///
			communist ///
			jw_persr_d_f? ///
			wave6 wave5 wave4 wave3 wave2 wave1  if(e(sample)==1), ///
		strata(transD) nohr breslow
	
	* Lijphart federalism index
	// see Appendix B
	
	* National government
	stcox 	dp_f?_3  norris_federalism_f? mnthsLastElect_f? sysCPL_EP sysCPL_Nat_f? ///
			natl_govt_f? ///
			age_f? female ///
			communist ///
			wave6 wave5 wave4 wave3 wave2 wave1  , ///
		strata(transD) nohr breslow
	
	* National delegation
	qui{	// merge in variable
		rename _merge _mOld
		replace country ="UK" if(country=="United Kingdom")
		merge country wave using "assembly files/EP Seats, by country-wave.dta", uniqusing sort keep(seatTotal seatsEP) nokeep
		tab _merge
		drop _merge
		rename _mOld _merge
		
		gen seatPerc = seatTotal/seatsEP
			label variable seatPerc "% of seats in wave, by country"
		foreach x of varlist seatPerc {
			gen `x'_f1 = cond(transD==1,`x',cond(`x'==., ., 0))
			gen `x'_f2 = cond(transD==2,`x',cond(`x'==., ., 0))
		}
	}
	stcox 	dp_f?_3  norris_federalism_f? mnthsLastElect_f? sysCPL_EP sysCPL_Nat_f? ///
			seatPerc_f? ///
			age_f? female ///
			communist ///
			wave6 wave5 wave4 wave3 wave2 wave1  , ///
		strata(transD) nohr breslow
		
	* Distance from Brussels
	stcox 	dp_f?_3  norris_federalism_f? mnthsLastElect_f? sysCPL_EP sysCPL_Nat_f? ///
			BXLdistance_f? ///
			age_f? female ///
			communist ///
			wave6 wave5 wave4 wave3 wave2 wave1  , ///
		strata(transD) nohr breslow
	
	* Proportional elections
	// If running piecemeal, be sure to run "merge in variable" code block under "Personal incentive"
	stcox 	dp_f?_3  norris_federalism_f? mnthsLastElect_f? sysCPL_EP sysCPL_Nat_f? ///
			dpi_pr_f? ///
			age_f? female ///
			communist ///
			wave6 wave5 wave4 wave3 wave2 wave1  , ///
		strata(transD) nohr breslow	
			
		