/*	Replication do-file
	Daniel and Metzger, "Within or Between Jobs?", JLS
	
	24SEP17
	
	DESCRIPTION:
		This file provides replication code to generate the paper's 2nd application
		dataset, and to	generate all figures and tables in the paper.  If the relevant 
		table/figure is generated in R, this file notes the R file's name.					
		
	REQUIRED PACKAGES:				
		* Stata: mstatecox (for PH tests; net install command embedded in do-file)
		* R: survival, mstate, foreign
	
	SOFTWARE VERSION:
		We used Stata 14.1 to generate the following tables and figures,
		and R 3.3.2 for the transition probability simulations.
		
*/
*******************************************************************************

******************** TO SET ********************

global dir "C:/Users/Shawna/Desktop/epDurat_replic/assembly files/"	// to define the local working directory
* global dir "/Users/metzger.356/Downloads/epDurat_replic/assembly files/"
															* note: PC needs forward slash at end of path.  Mac is indifferent.													
************************************************
// Rest can run as is
cd "$dir"


// Dataset assembly 
qui do "../_1 - dataset assembly file.do"	// Assemble the dataset, using Daniel 2015's book dataset as base.
qui do "_2 - mstate conversion.do"			// Convert into proper form for analysis.


// Tables 1-3
do "_3 - paper tables.do"


// Figures
	* Generated in R. 
	* FILE: "Figure 1a.R"	 [generates "figures/sim results/Simulations - Fig 2a.Rdata" + Stata versions of the files]
	* FILE: "Figure 1b.R"	 [generates "figures/sim results/Simulations - Fig 2b.Rdata" + Stata versions of the files]
	* FILE: "Figure 2a.R"	 [generates "figures/sim results/Simulations - Fig 3a.Rdata" + Stata versions of the files]
	* FILE: "Figure 2b.R"	 [generates "figures/sim results/Simulations - Fig 3b.Rdata" + Stata versions of the files]
	
		*** CAUTION: Simulation code takes 30-90 minutes to run.
		*		 	 If only interested in replicating graphs, run the "graph - ..." do-files only
	  
// Once R files are all run:
qui do "figures/graph - Figure 1a.do"
qui do "figures/graph - Figure 1b.do"
qui do "figures/graph - Figure 2a.do"
qui do "figures/graph - Figure 2b.do"


// Appendices
do "_5 - appendices.do"


graph close _all
