
#############################################
######### Use Non-Panel, long data ##########
#############################################
rm(list=ls())
library(foreign)
library(survival)
library(mstate)


setwd("C:/Users/Shawna/Desktop/epDurat_replic")

dat.gap <- read.dta("2 - mep - mstate ready.dta")

dat.gap$from <- dat.gap$stage
dat.gap$to <- dat.gap$nextStage
dat.gap$start <- dat.gap$t0
dat.gap$stop <- dat.gap$mnthsWv

source("alt_mssample.R")

setwd("figures/sim results")

#####################################
##### Prepare Transition Matrix #####
#####################################

#Use Matric Omitting Other Category
tmat <- transMat(list(c(2),    #transitions from sitting
			c(1)), 		 	   #transitions from dropout
			names = c("seated", "dropout"))

##### Convert Data Type
attr(dat.gap, "trans") <- tmat
class(dat.gap) <- c("msdata", "data.frame")


#############################################
###### Estimate Semi-Parametric Models ######
#############################################

# For the pred probs for Table 1, use Model 2 in paper, which is mod_1 in the Stata results:
mod.1.gap <- coxph(Surv(start, stop, status) ~  
                       dp_f1_3 + dp_f2_3 + norris_federalism_f1 + norris_federalism_f2 +
                       mnthsLastElect_f1 + mnthsLastElect_f2 + sysCPL_EP +
                       sysCPL_Nat_f1 + sysCPL_Nat_f2 +
                       age_f1 + age_f2 + female + communist +
                       wave6 + wave5 + wave4 + wave3 + wave2 + wave1 +
                       strata(transD), data = dat.gap, method = "breslow")
summary(mod.1.gap)

   
##################################################
##### Plot Results of Semi-Parametric Models #####
##################################################

#####Set CPL @ nat to 0 first.
sysCPL_Nat_f1 <- as.vector(c(0,0))
sysCPL_Nat_f2 <- as.vector(c(0,0))

# wave at 6.
wave1 <- as.vector(c(0,0))
wave2 <- as.vector(c(0,0))
wave3 <- as.vector(c(0,0))
wave4 <- as.vector(c(0,0))
wave5 <- as.vector(c(0,0))
wave6 <- as.vector(c(1,1))


# all else at median.
med <- quantile(dat.gap$norris_federalism, .5, na.rm=TRUE)
    norris_federalism_f1 <- as.vector(c(med,0))
    norris_federalism_f2 <- as.vector(c(0,med))

med <- quantile(dat.gap$mnthsLastElect, .5, na.rm=TRUE)    
    mnthsLastElect_f1 <- as.vector(c(med,0))
    mnthsLastElect_f2 <- as.vector(c(0,med))

sysCPL_EP <- as.vector(c(rep(quantile(dat.gap$sysCPL_EP, .5, na.rm=TRUE), 2)))

med <- quantile(dat.gap$dp_3, .5, na.rm=TRUE) 
    dp_f1_3 <- as.vector(c(med,0))
    dp_f2_3 <- as.vector(c(0,med))

med <- quantile(dat.gap$age, .5, na.rm=TRUE)         
    age_f1 <- as.vector(c(med,0))
    age_f2 <- as.vector(c(0,med))

female <- as.vector(c(rep(quantile(dat.gap$female, .5, na.rm=TRUE), 2)))
communist <- as.vector(c(rep(quantile(dat.gap$communist, .5, na.rm=TRUE), 2)))

sit.Fig1.PanelB.dp0 <- data.frame(cbind(
    dp_f1_3 , dp_f2_3 , norris_federalism_f1 , norris_federalism_f2 ,
        mnthsLastElect_f1 , mnthsLastElect_f2 , sysCPL_EP ,
        sysCPL_Nat_f1 , sysCPL_Nat_f2 ,
        age_f1 , age_f2 , female , communist ,
        wave6 , wave5 , wave4 , wave3 , wave2 , wave1 
	))

sit.Fig1.PanelB.dp0$trans <- 1:2
attr(sit.Fig1.PanelB.dp0, "trans") <- tmat
class(sit.Fig1.PanelB.dp0) <- c("msdata", "data.frame")
sit.Fig1.PanelB.dp0$strata<-sit.Fig1.PanelB.dp0$trans


msf.Fig1.PanelB.dp0 <- msfit(mod.1.gap, sit.Fig1.PanelB.dp0, trans=tmat, variance=TRUE)

#########Set dp to 1.
sysCPL_Nat_f1 <- as.vector(c(1,1))
sysCPL_Nat_f2 <- as.vector(c(1,1))


sit.Fig1.PanelB.dp1 <- data.frame(cbind(
    dp_f1_3 , dp_f2_3 , norris_federalism_f1 , norris_federalism_f2 ,
    mnthsLastElect_f1 , mnthsLastElect_f2 , sysCPL_EP ,
    sysCPL_Nat_f1 , sysCPL_Nat_f2 ,
    age_f1 , age_f2 , female , communist ,
    wave6 , wave5 , wave4 , wave3 , wave2 , wave1 
))

sit.Fig1.PanelB.dp1$trans <- 1:2
attr(sit.Fig1.PanelB.dp1, "trans") <- tmat
class(sit.Fig1.PanelB.dp1) <- c("msdata", "data.frame")
sit.Fig1.PanelB.dp1$strata<-sit.Fig1.PanelB.dp1$trans

msf.Fig1.PanelB.dp1 <- msfit(mod.1.gap, sit.Fig1.PanelB.dp1, trans=tmat, variance=TRUE)

###################################################
##### Generate the Same Results Employing CIs #####
###################################################

tv <- seq(1,60)

# trying a loop
sims <- 1000
nIndvs <- 750   


####Simulations for dp==0 In Stage 1 at Time 0
set.seed(072616)
    # first loop
    s <- 1
    temp <- mssamplea(Haz = msf.Fig1.PanelB.dp0$Haz, trans = tmat, tvec=tv, history=list(state=1, time=0), M=nIndvs, clock="reset", output="state")
    transPrs <- cbind(s, temp)
    
    for(s in 2:sims) {
        print(s)
        temp <-mssamplea(Haz = msf.Fig1.PanelB.dp0$Haz, trans = tmat, tvec=tv, history=list(state=1, time=0), M=nIndvs, clock="reset", output="state")
        temp <- cbind(s, temp) 
        transPrs <- rbind(transPrs, temp)
    }
    names(transPrs)[1] <- "simNo"
    
# WRITE FINAL PROCESSING HERE
final <- matrix(0, length(tv), dim(tmat)[1]*3 + 1)

for(t in 1:60)     {
    final[t,1] <- t 
    
    # stage 1
    final[t,2] <- mean(transPrs$pstate1[transPrs$time==t])
    final[t,3] <- quantile(transPrs$pstate1[transPrs$time==t], .025)
    final[t,4] <- quantile(transPrs$pstate1[transPrs$time==t], .975)
    
    # stage 2
    final[t,5] <- mean(transPrs$pstate2[transPrs$time==t])
    final[t,6] <- quantile(transPrs$pstate2[transPrs$time==t], .025)
    final[t,7] <- quantile(transPrs$pstate2[transPrs$time==t], .975)
    
}
final.Fig1.PanelB.dp0 <- data.frame(final)
names(final.Fig1.PanelB.dp0) <- c("t",  "pstate1", "pstate1_l", "pstate1_u", "pstate2", "pstate2_l", "pstate2_u")

save.image("Simulations - Fig 2b.Rdata")                       

####Simulations for dp==0 In Stage 1 at Time 0
set.seed(260716)
    # first loop
    s <- 1
    temp <- mssamplea(Haz = msf.Fig1.PanelB.dp1$Haz, trans = tmat, tvec=tv, history=list(state=1, time=0), M=nIndvs, clock="reset", output="state")
    transPrs <- cbind(s, temp)
    
    for(s in 2:sims) {
        print(s)
        temp <-mssamplea(Haz = msf.Fig1.PanelB.dp1$Haz, trans = tmat, tvec=tv, history=list(state=1, time=0), M=nIndvs, clock="reset", output="state")
        temp <- cbind(s, temp) 
        transPrs <- rbind(transPrs, temp)
    }
    names(transPrs)[1] <- "simNo"
    
# WRITE FINAL PROCESSING HERE
final <- matrix(0, length(tv), dim(tmat)[1]*3 + 1)

for(t in 1:60)     {
    final[t,1] <- t 

    # stage 1
    final[t,2] <- mean(transPrs$pstate1[transPrs$time==t])
    final[t,3] <- quantile(transPrs$pstate1[transPrs$time==t], .025)
    final[t,4] <- quantile(transPrs$pstate1[transPrs$time==t], .975)
    
    # stage 2
    final[t,5] <- mean(transPrs$pstate2[transPrs$time==t])
    final[t,6] <- quantile(transPrs$pstate2[transPrs$time==t], .025)
    final[t,7] <- quantile(transPrs$pstate2[transPrs$time==t], .975)
    
}
final.Fig1.PanelB.dp1 <- data.frame(final)
names(final.Fig1.PanelB.dp1) <- c("t",  "pstate1", "pstate1_l", "pstate1_u", "pstate2", "pstate2_l", "pstate2_u")
                 
save.image("Simulations - Fig 2b.Rdata")                     
   
write.dta(final.Fig1.PanelB.dp0, "Figure 2b - dp0.dta")
write.dta(final.Fig1.PanelB.dp1, "Figure 2b - dp1.dta")
