
#############################################
######### Use Non-Panel, long data ##########
#############################################
rm(list=ls())
library(foreign)
library(survival)
library(mstate)


setwd("C:/Users/Shawna/Desktop/epDurat_replic")

dat.gap <- read.dta("2 - mep - mstate ready.dta")

dat.gap$from <- dat.gap$stage
dat.gap$to <- dat.gap$nextStage
dat.gap$start <- dat.gap$t0
dat.gap$stop <- dat.gap$mnthsWv

source("alt_mssample.R")

setwd("figures/sim results")
#####################################
##### Prepare Transition Matrix #####
#####################################

#Use Matric Omitting Other Category
tmat <- transMat(list(c(2),    #transitions from sitting
			c(1)), 		 	   #transitions from dropout
			names = c("seated", "dropout"))

##### Convert Data Type
attr(dat.gap, "trans") <- tmat
class(dat.gap) <- c("msdata", "data.frame")


#############################################
###### Estimate Semi-Parametric Models ######
#############################################

mod.1i.gap <- coxph(Surv(start, stop, status) ~  
                       dp_f1_3 + dp_f2_3 + norris_federalism_f1 + norris_federalism_f2 +
                       mnthsLastElect_f1 + mnthsLastElect_f2 + sysCPL_EP +
                       sysCPL_Nat_f1 + sysCPL_Nat_f2 +
                       age_f1 + age_f2 + female + communist +
                       wave6 + wave5 + wave4 + wave3 + wave2 + wave1 +
                       dp_f1_3*mnthsLastElect_f1 + norris_federalism_f1*mnthsLastElect_f1 + sysCPL_Nat_f1*mnthsLastElect_f1 +
                       strata(transD), data = dat.gap, method = "breslow")
summary(mod.1i.gap)

##################################################
##### Plot Results of Semi-Parametric Models #####
##################################################


#####Set mtnshLastElect to ~25th percentile (approximately 12 months)
month <- 12

mnthsLastElect_f1 <- as.vector(c(month,0))  
mnthsLastElect_f2 <- as.vector(c(0,month))

# wave at 6.
wave1 <- as.vector(c(0,0))
wave2 <- as.vector(c(0,0))
wave3 <- as.vector(c(0,0))
wave4 <- as.vector(c(0,0))
wave5 <- as.vector(c(0,0))
wave6 <- as.vector(c(1,1))

# country with direct subnatl exec + leg elections
medDPI <- 1
dp_f1_3 <- as.vector(c(medDPI,0))
dp_f2_3 <- as.vector(c(0,medDPI))
dp_f1_3.mnthsLastElect_f1 <- as.vector(c(medDPI*month,0)) 

# norris    
medNorris <- 0   
norris_federalism_f1 <- as.vector(c(medNorris,0))
norris_federalism_f2 <- as.vector(c(0,medNorris))
norris_federalism_f1.mnthsLastElect_f1 <- as.vector(c(medNorris*month,0))   

# CPL 
medCPL <- 1
sysCPL_Nat_f1 <- as.vector(c(medCPL,0))
sysCPL_Nat_f2 <- as.vector(c(0,medCPL))
mnthsLastElect_f1.sysCPL_Nat_f1 <- as.vector(c(medCPL*month,0))



# all else at median.
sysCPL_EP <- as.vector(c(rep(quantile(dat.gap$sysCPL_EP, .5, na.rm=TRUE), 2)))

med <- quantile(dat.gap$age, .5, na.rm=TRUE)         
age_f1 <- as.vector(c(med,0))
age_f2 <- as.vector(c(0,med))

female <- as.vector(c(rep(quantile(dat.gap$female, .5, na.rm=TRUE), 2)))
communist <- as.vector(c(rep(quantile(dat.gap$communist, .5, na.rm=TRUE), 2)))

sit.Fig1.PanelC.dp0 <- data.frame(cbind(
    dp_f1_3 , dp_f2_3 , norris_federalism_f1 , norris_federalism_f2 ,
    mnthsLastElect_f1 , mnthsLastElect_f2 , sysCPL_EP ,
    sysCPL_Nat_f1 , sysCPL_Nat_f2 ,
    age_f1 , age_f2 , female , communist ,
    wave6 , wave5 , wave4 , wave3 , wave2 , wave1 ,
    dp_f1_3.mnthsLastElect_f1, norris_federalism_f1.mnthsLastElect_f1, mnthsLastElect_f1.sysCPL_Nat_f1
))

sit.Fig1.PanelC.dp0$trans <- 1:2
attr(sit.Fig1.PanelC.dp0, "trans") <- tmat
class(sit.Fig1.PanelC.dp0) <- c("msdata", "data.frame")
sit.Fig1.PanelC.dp0$strata<-sit.Fig1.PanelC.dp0$trans

msf.Fig1.PanelC.dp0 <- msfit(mod.1i.gap, sit.Fig1.PanelC.dp0, trans=tmat, variance=TRUE)

#########Set lastElect to 50th percentile (~24 months).

month <- 24

mnthsLastElect_f1 <- as.vector(c(month,0))  
mnthsLastElect_f2 <- as.vector(c(0,month))

# country with direct subnatl exec + leg elections
dp_f1_3.mnthsLastElect_f1 <- as.vector(c(medDPI*month,0)) 

# norris
norris_federalism_f1.mnthsLastElect_f1 <- as.vector(c(medNorris*month,0))

# CPL
mnthsLastElect_f1.sysCPL_Nat_f1 <- as.vector(c(medCPL*month,0))


sit.Fig1.PanelC.dp1 <- data.frame(cbind(
    dp_f1_3 , dp_f2_3 , norris_federalism_f1 , norris_federalism_f2 ,
    mnthsLastElect_f1 , mnthsLastElect_f2 , sysCPL_EP ,
    sysCPL_Nat_f1 , sysCPL_Nat_f2 ,
    age_f1 , age_f2 , female , communist ,
    wave6 , wave5 , wave4 , wave3 , wave2 , wave1,
    dp_f1_3.mnthsLastElect_f1, norris_federalism_f1.mnthsLastElect_f1, mnthsLastElect_f1.sysCPL_Nat_f1
))

sit.Fig1.PanelC.dp1$trans <- 1:2
attr(sit.Fig1.PanelC.dp1, "trans") <- tmat
class(sit.Fig1.PanelC.dp1) <- c("msdata", "data.frame")
sit.Fig1.PanelC.dp1$strata<-sit.Fig1.PanelC.dp1$trans

msf.Fig1.PanelC.dp1 <- msfit(mod.1i.gap, sit.Fig1.PanelC.dp1, trans=tmat, variance=TRUE)

#########Set lastElect to ~75th percentile (~36 months).

month <- 36

mnthsLastElect_f1 <- as.vector(c(month,0))  
mnthsLastElect_f2 <- as.vector(c(0,month))

# country with direct subnatl exec + leg elections
dp_f1_3.mnthsLastElect_f1 <- as.vector(c(medDPI*month,0)) 

# norris
norris_federalism_f1.mnthsLastElect_f1 <- as.vector(c(medNorris*month,0))

# CPL
mnthsLastElect_f1.sysCPL_Nat_f1 <- as.vector(c(medCPL*month,0))


sit.Fig1.PanelC.dp2 <- data.frame(cbind(
    dp_f1_3 , dp_f2_3 , norris_federalism_f1 , norris_federalism_f2 ,
    mnthsLastElect_f1 , mnthsLastElect_f2 , sysCPL_EP ,
    sysCPL_Nat_f1 , sysCPL_Nat_f2 ,
    age_f1 , age_f2 , female , communist ,
    wave6 , wave5 , wave4 , wave3 , wave2 , wave1,
    dp_f1_3.mnthsLastElect_f1, norris_federalism_f1.mnthsLastElect_f1, mnthsLastElect_f1.sysCPL_Nat_f1
))

sit.Fig1.PanelC.dp2$trans <- 1:2
attr(sit.Fig1.PanelC.dp2, "trans") <- tmat
class(sit.Fig1.PanelC.dp2) <- c("msdata", "data.frame")
sit.Fig1.PanelC.dp2$strata<-sit.Fig1.PanelC.dp2$trans

msf.Fig1.PanelC.dp2 <- msfit(mod.1i.gap, sit.Fig1.PanelC.dp2, trans=tmat, variance=TRUE)

###################################################
##### Generate the Same Results Employing CIs #####
###################################################

#Simulations for Lo GDP In Stage 1 at Time 0
tv <- seq(1,60)

# trying a loop
sims <- 1000
nIndvs <- 750 


####Simulations for dp==0 In Stage 1 at Time 0
set.seed(01081979)
    # first loop
    s <- 1
    temp <- mssamplea(Haz = msf.Fig1.PanelC.dp0$Haz, trans = tmat, tvec=tv, history=list(state=1, time=0), M=nIndvs, clock="reset", output="state")
    transPrs <- cbind(s, temp)
    
    for(s in 2:sims) {
        print(s)
        temp <-mssamplea(Haz = msf.Fig1.PanelC.dp0$Haz, trans = tmat, tvec=tv, history=list(state=1, time=0), M=nIndvs, clock="reset", output="state")
        temp <- cbind(s, temp) 
        transPrs <- rbind(transPrs, temp)
    }
    names(transPrs)[1] <- "simNo"
    
# WRITE FINAL PROCESSING HERE
final <- matrix(0, length(tv), dim(tmat)[1]*3 + 1)

for(t in 1:60)     {
    final[t,1] <- t 
    
    # stage 1
    final[t,2] <- mean(transPrs$pstate1[transPrs$time==t])
    final[t,3] <- quantile(transPrs$pstate1[transPrs$time==t], .025)
    final[t,4] <- quantile(transPrs$pstate1[transPrs$time==t], .975)
    
    # stage 2
    final[t,5] <- mean(transPrs$pstate2[transPrs$time==t])
    final[t,6] <- quantile(transPrs$pstate2[transPrs$time==t], .025)
    final[t,7] <- quantile(transPrs$pstate2[transPrs$time==t], .975)
    
}
final.Fig1.PanelC.dp0 <- data.frame(final)
names(final.Fig1.PanelC.dp0) <- c("t",  "pstate1", "pstate1_l", "pstate1_u", "pstate2", "pstate2_l", "pstate2_u")
 
save.image("Simulations - Fig 3.Rdata")                       

####Simulations for dp==1 In Stage 1 at Time 0
set.seed(08011979)
    # first loop
    s <- 1
    temp <- mssamplea(Haz = msf.Fig1.PanelC.dp1$Haz, trans = tmat, tvec=tv, history=list(state=1, time=0), M=nIndvs, clock="reset", output="state")
    transPrs <- cbind(s, temp)
    
    for(s in 2:sims) {
        print(s)
        temp <-mssamplea(Haz = msf.Fig1.PanelC.dp1$Haz, trans = tmat, tvec=tv, history=list(state=1, time=0), M=nIndvs, clock="reset", output="state")
        temp <- cbind(s, temp) 
        transPrs <- rbind(transPrs, temp)
    }
    names(transPrs)[1] <- "simNo"
    
# WRITE FINAL PROCESSING HERE
final <- matrix(0, length(tv), dim(tmat)[1]*3 + 1)

for(t in 1:60)     {
    final[t,1] <- t 
    
    # stage 1
    final[t,2] <- mean(transPrs$pstate1[transPrs$time==t])
    final[t,3] <- quantile(transPrs$pstate1[transPrs$time==t], .025)
    final[t,4] <- quantile(transPrs$pstate1[transPrs$time==t], .975)
    
    # stage 2
    final[t,5] <- mean(transPrs$pstate2[transPrs$time==t])
    final[t,6] <- quantile(transPrs$pstate2[transPrs$time==t], .025)
    final[t,7] <- quantile(transPrs$pstate2[transPrs$time==t], .975)
    
}
final.Fig1.PanelC.dp1 <- data.frame(final)
names(final.Fig1.PanelC.dp1) <- c("t",  "pstate1", "pstate1_l", "pstate1_u", "pstate2", "pstate2_l", "pstate2_u")
                 
save.image("Simulations - Fig 3.Rdata")  

####Simulations for dp==3 In Stage 1 at Time 0
set.seed(06011984)
# first loop
s <- 1
temp <- mssamplea(Haz = msf.Fig1.PanelC.dp2$Haz, trans = tmat, tvec=tv, history=list(state=1, time=0), M=nIndvs, clock="reset", output="state")
transPrs <- cbind(s, temp)

for(s in 2:sims) {
    print(s)
    temp <-mssamplea(Haz = msf.Fig1.PanelC.dp2$Haz, trans = tmat, tvec=tv, history=list(state=1, time=0), M=nIndvs, clock="reset", output="state")
    temp <- cbind(s, temp) 
    transPrs <- rbind(transPrs, temp)
}
names(transPrs)[1] <- "simNo"

# WRITE FINAL PROCESSING HERE
final <- matrix(0, length(tv), dim(tmat)[1]*3 + 1)

for(t in 1:60)     {
    final[t,1] <- t 
    
    # stage 1
    final[t,2] <- mean(transPrs$pstate1[transPrs$time==t])
    final[t,3] <- quantile(transPrs$pstate1[transPrs$time==t], .025)
    final[t,4] <- quantile(transPrs$pstate1[transPrs$time==t], .975)
    
    # stage 2
    final[t,5] <- mean(transPrs$pstate2[transPrs$time==t])
    final[t,6] <- quantile(transPrs$pstate2[transPrs$time==t], .025)
    final[t,7] <- quantile(transPrs$pstate2[transPrs$time==t], .975)
    
}
final.Fig1.PanelC.dp2 <- data.frame(final)
names(final.Fig1.PanelC.dp2) <- c("t",  "pstate1", "pstate1_l", "pstate1_u", "pstate2", "pstate2_l", "pstate2_u")

save.image("Simulations - Fig 3.Rdata")    

write.dta(final.Fig1.PanelC.dp0, "Figure 3 - mn12.dta")
write.dta(final.Fig1.PanelC.dp1, "Figure 3 - mn24.dta")
write.dta(final.Fig1.PanelC.dp2, "Figure 3 - mn36.dta")
